<?php

/**
 * @file
 * Page callbacks for the role_activity module.
 */

/**
 * Review role activity log.
 */
function role_activity_log() {
  $header = array(
    array('data' => t('Timestamp'), 'field' => 'timestamp', 'sort' => 'desc'),
    array('data' => t('Action'),    'field' => 'action'),
    array('data' => t('User'),      'field' => 'uid'),
    array('data' => t('Activity')),
    array('data' => t('Path'),      'field' => 'uri'),
    array('data' => t('IP/Host'),   'field' => 'ip'),
    array('data' => t('Type'),      'field' => 'type'),
    array('data' => t('Message'),   'field' => 'message'),
    array('data' => t('Referrer'),  'field' => 'referer'),
    array('data' => t('Link')),
  );

  $sql = 'SELECT * FROM {role_activity} '. tablesort_sql($header);
  $result = pager_query($sql, 50);

  $rows = array();
  while ($log = db_fetch_object($result)) {
    $host = $log->ip;
    $account = user_load(array('uid' => $log->uid));

    $rows[] = array(
      array('data' => format_date($log->timestamp, 'small'), 'nowrap' => 'nowrap'),
      array('data' => $log->action),
      array('data' => theme('username', $account)),
      array('data' => l(t('Activity'), 'admin/reports/role_activity/user/'. $account->uid)),
      array('data' => $log->uri),
      l($host, 'http://whois.domaintools.com/'. $log->ip),
      array('data' => $log->type),
      array('data' => $log->message),
      _role_activity_format_path($log->referer),
      $log->link,
    );
  }

  if (empty($rows)) {
    $rows[] = array(array(
      'data' => t('No activity available.'),
      'colspan' => count($header),
    ));
  }

  return theme('table', $header, $rows) . theme('pager', NULL, 50, 0);
}

/**
 * Top users by activity on the site.
 */
function role_activity_top_users() {
  $header = array(
    array('data' => t('User'),     'field' => 'uid'),
    array('data' => t('Activity')),
    array('data' => t('Number of events'), 'field' => 'count', 'sort' => 'desc'),
    array('data' => t('Last'),     'field' => 'last'),
  );

  $sql = 'SELECT uid, COUNT(*) AS count, MAX(timestamp) AS last FROM {role_activity} GROUP BY uid '. tablesort_sql($header);
  $result = pager_query($sql, 50);

  $rows = array();
  while ($log = db_fetch_object($result)) {
    $account = user_load(array('uid' => $log->uid));

    $rows[] = array(
      array('data' => theme('username', $account)),
      array('data' => l(t('Activity'), 'admin/reports/role_activity/user/'. $account->uid)),
      array('data' => $log->count, 'align' => 'right'),
      array('data' => format_date($log->last, 'small'), 'nowrap' => 'nowrap'),
    );
  }

  if (empty($rows)) {
    $rows[] = array(array(
      'data' => t('No activity available.'),
      'colspan' => count($header),
    ));
  }

  return theme('table', $header, $rows) . theme('pager', NULL, 50, 0);
}

/**
 * Per-user activity data display on the site.
 */
function role_activity_by_user($account) {
  $header = array(
    array('data' => t('Timestamp'), 'field' => 'timestamp', 'sort' => 'desc'),
    array('data' => t('Action'),    'field' => 'action'),
    array('data' => t('Path'),      'field' => 'uri'),
    array('data' => t('IP/Host'),   'field' => 'ip'),
    array('data' => t('Type'),      'field' => 'type'),
    array('data' => t('Message'),   'field' => 'message'),
    array('data' => t('Referrer'),  'field' => 'referer'),
    array('data' => t('Link')),
  );

  $sql = 'SELECT * FROM {role_activity} WHERE uid = %d '. tablesort_sql($header);
  $result = pager_query($sql, 50, 0, NULL, $account->uid);

  $rows = array();
  while ($log = db_fetch_object($result)) {
    $host = $log->ip;

    $rows[] = array(
      array('data' => format_date($log->timestamp, 'small'), 'nowrap' => 'nowrap'),
      array('data' => $log->action),
      array('data' => $log->uri),
      l($host, 'http://whois.domaintools.com/'. $log->ip),
      array('data' => $log->type),
      array('data' => $log->message),
      _role_activity_format_path($log->referer),
      $log->link,
    );
  }

  if (empty($rows)) {
    $rows[] = array(array(
      'data' => t('No activity available for this user.'),
      'colspan' => count($header),
    ));
  }

  $output = t('Details for !user', array('!user' => theme('username', $account)));
  return $output . theme('table', $header, $rows) . theme('pager', NULL, 50, 0);
}
